pub struct SourceMapComposer { /* private fields */ }Expand description
Composer for combining multiple source maps.
When you have a chain of transformations, you can compose the source maps to get a direct mapping from the original source to the final output.
Implementations